Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <campbell@blender.org>2022-03-30 09:26:42 +0300
committerCampbell Barton <campbell@blender.org>2022-03-30 10:01:22 +0300
commita8ec7845e0bdb9e63e9d3dbd7f4cd7caad36b5a2 (patch)
tree4531232281ddc4cda4df3fb1ccc0822018fe5682 /source/blender/blenlib/BLI_polyfill_2d.h
parentaf3aaf80344e745e6c207102941513cb631194c3 (diff)
Cleanup: use "num" as a suffix in: source/blender/blenlib
Also replace "num" with: - "number" when it's not used to denote the number of items. - "digits" when digits in a string are being manipulated.
Diffstat (limited to 'source/blender/blenlib/BLI_polyfill_2d.h')
-rw-r--r--source/blender/blenlib/BLI_polyfill_2d.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/source/blender/blenlib/BLI_polyfill_2d.h b/source/blender/blenlib/BLI_polyfill_2d.h
index a551188737f..ccb4c856de3 100644
--- a/source/blender/blenlib/BLI_polyfill_2d.h
+++ b/source/blender/blenlib/BLI_polyfill_2d.h
@@ -16,7 +16,7 @@ struct MemArena;
* A version of #BLI_polyfill_calc that uses a memory arena to avoid re-allocations.
*/
void BLI_polyfill_calc_arena(const float (*coords)[2],
- unsigned int coords_tot,
+ unsigned int coords_num,
int coords_sign,
unsigned int (*r_tris)[3],
@@ -27,16 +27,16 @@ void BLI_polyfill_calc_arena(const float (*coords)[2],
*
* \param coords: 2D coordinates describing vertices of the polygon,
* in either clockwise or counterclockwise order.
* \param coords_tot: Total points in the array.
* \param coords_sign: Pass this when we know the sign in advance to avoid extra calculations.
*
* \param r_tris: This array is filled in with triangle indices in clockwise order.
* The length of the array must be `coords_tot - 2`.
* Indices are guaranteed to be assigned to unique triangles, with valid indices,
* even in the case of degenerate input (self intersecting polygons, zero area ears... etc).
*/
void BLI_polyfill_calc(const float (*coords)[2],
- unsigned int coords_tot,
+ unsigned int coords_num,
int coords_sign,
unsigned int (*r_tris)[3]);
@@ -27,16 +27,16 @@ void BLI_polyfill_calc_arena(const float (*coords)[2],
* \param coords: 2D coordinates describing vertices of the polygon,
* in either clockwise or counterclockwise order.
- * \param coords_tot: Total points in the array.
+ * \param coords_num: Total points in the array.
* \param coords_sign: Pass this when we know the sign in advance to avoid extra calculations.
*
@@ -27,16 +27,16 @@ void BLI_polyfill_calc_arena(const float (*coords)[2],
*
* \param r_tris: This array is filled in with triangle indices in clockwise order.
- * The length of the array must be `coords_tot - 2`.
+ * The length of the array must be `coords_num - 2`.
* Indices are guaranteed to be assigned to unique triangles, with valid indices,
* even in the case of degenerate input (self intersecting polygons, zero area ears... etc).